package com.sillycycle.bagleyd.threed;

/*
 * @(#)ThreedSurfaceSort.java
 *
 * Copyright 2005 - 2014  David A. Bagley, bagleyd AT verizon.net
 *
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and
 * that both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of the author not be
 * used in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 *
 * This program is distributed in the hope that it will be "useful",
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

import java.util.Arrays;
import java.util.Comparator;

/**
 * The <code>ThreedSurfaceSort</code> class tries to put the surfaces
 * in the proper order for the <code>ThreedFrame</code> class.
 *
 * @author	David A. Bagley
 * @author	bagleyd AT verizon.net
 * @author	https://www.sillycycle.com/threed.html
 */

public class ThreedSurfaceSort {
	private ThreedSurfaceSort() {
	}

	public static void sort(ThreedSurface[] surf) {
		Comparator<ThreedSurface> surfaceComparator = // Java 1.5
		//Comparator surfaceComparator =
			new ThreedSurfaceComparator();
		Arrays.sort(surf, surfaceComparator);
	}
}

/* This comparator will compare two ThreedSurface objects and
   return -1, 0, or +1 depending on their relative order. */
class ThreedSurfaceComparator implements
		Comparator<ThreedSurface> // Java 1.5
		//Comparator
{
	@Override
	public int compare(ThreedSurface elem1, ThreedSurface elem2)
	{
		/*object.vertex[elem1.depthIndex].eye.z
		  object.vertex[elem2.depthIndex].eye.z */
		if (elem1.averageDepth > elem2.averageDepth)
			return -1;
		if (elem2.averageDepth > elem1.averageDepth)
			return 1;
		return 0;
	}
}
